typedef union {
  long itype; 
  tree ttype; 
  char *strtype; 
  enum tree_code code; 
  flagged_type_tree ftype;
  struct unparsed_text *pi;
} YYSTYPE;
#define	IDENTIFIER	257
#define	TYPENAME	258
#define	SELFNAME	259
#define	PFUNCNAME	260
#define	SCSPEC	261
#define	TYPESPEC	262
#define	CV_QUALIFIER	263
#define	CONSTANT	264
#define	STRING	265
#define	ELLIPSIS	266
#define	SIZEOF	267
#define	ENUM	268
#define	IF	269
#define	ELSE	270
#define	WHILE	271
#define	DO	272
#define	FOR	273
#define	SWITCH	274
#define	CASE	275
#define	DEFAULT	276
#define	BREAK	277
#define	CONTINUE	278
#define	RETURN_KEYWORD	279
#define	GOTO	280
#define	ASM_KEYWORD	281
#define	TYPEOF	282
#define	ALIGNOF	283
#define	SIGOF	284
#define	ATTRIBUTE	285
#define	EXTENSION	286
#define	LABEL	287
#define	REALPART	288
#define	IMAGPART	289
#define	VA_ARG	290
#define	AGGR	291
#define	VISSPEC	292
#define	DELETE	293
#define	NEW	294
#define	THIS	295
#define	OPERATOR	296
#define	CXX_TRUE	297
#define	CXX_FALSE	298
#define	NAMESPACE	299
#define	TYPENAME_KEYWORD	300
#define	USING	301
#define	LEFT_RIGHT	302
#define	TEMPLATE	303
#define	TYPEID	304
#define	DYNAMIC_CAST	305
#define	STATIC_CAST	306
#define	REINTERPRET_CAST	307
#define	CONST_CAST	308
#define	SCOPE	309
#define	EXPORT	310
#define	EMPTY	311
#define	PTYPENAME	312
#define	NSNAME	313
#define	THROW	314
#define	ASSIGN	315
#define	OROR	316
#define	ANDAND	317
#define	MIN_MAX	318
#define	EQCOMPARE	319
#define	ARITHCOMPARE	320
#define	LSHIFT	321
#define	RSHIFT	322
#define	POINTSAT_STAR	323
#define	DOT_STAR	324
#define	UNARY	325
#define	PLUSPLUS	326
#define	MINUSMINUS	327
#define	HYPERUNARY	328
#define	POINTSAT	329
#define	TRY	330
#define	CATCH	331
#define	EXTERN_LANG_STRING	332
#define	ALL	333
#define	PRE_PARSED_CLASS_DECL	334
#define	DEFARG	335
#define	DEFARG_MARKER	336
#define	PRE_PARSED_FUNCTION_DECL	337
#define	TYPENAME_DEFN	338
#define	IDENTIFIER_DEFN	339
#define	PTYPENAME_DEFN	340
#define	END_OF_LINE	341
#define	END_OF_SAVED_INPUT	342


extern YYSTYPE yylval;
#define YYEMPTY		-2
